//
// vrml.cpp
//

#include  "truss.h"

void vrml_truss (ofstream &outFile, double node1[3], double node2[3], double force) {
// Draws the function defined in ftheta on the canvas
//  outFile: pointer to the output vrml file
//  node1,2: two end points of a truss member
//  force:   the magnitute of the force in the truss member

	outFile << "# Draw truss member\n";
	outFile << "#-----------------------------------\n";
	outFile << "Transform {\n";
	outFile << "\ttranslation 0 0 0";
	outFile << "\tchildren Shape {\n";
	outFile << "\t\tappearance Appearance {\n";
	outFile << "\t\t\tmaterial Material {\n";
	if (force < -EPS)       // in tension
		outFile << "\t\t\t\tdiffuseColor 1 0 0\n\t\t\t}\n\t\t}\n";
	else if (force > EPS)   // in compression
		outFile << "\t\t\t\tdiffuseColor 0 0 1\n\t\t\t}\n\t\t}\n";
	else                    // neutral
		outFile << "\t\t\t\tdiffuseColor 1 0 1\n\t\t\t}\n\t\t}\n";
	outFile << "\t\tgeometry Extrusion {\n";
	outFile << "\t\t\tcrossSection [1 0, 0 -1, -1 0, 0 1, 1 0]\n";
	outFile << "\t\t\tscale ["<<TRUSS_WIDTH<<" "<<TRUSS_WIDTH<<"]\n";
	outFile << "\t\t\tspine [";
	outFile << node1[0]<<" "<<node1[1]<<" "<<node1[2]<<", "
	        << node2[0]<<" "<<node2[1]<<" "<<node2[2]<<"]\n";
	outFile << "\t\t}\n\t}\n}\n";

	outFile << "# Draw force string\n";
	outFile << "#-----------------------------------\n";
	outFile << "Transform {\n";
	outFile << "\ttranslation "<<0.5*(node1[0]+node2[0])<<" "
	                           <<0.5*(node1[1]+node2[1])-0.3<<" "
	                           <<0.5*(node1[2]+node2[2])+0.3<<"\n";
	outFile << "\tchildren Shape {\n";
	outFile << "\t\tappearance Appearance {\n";
	outFile << "\t\t\tmaterial Material {\n";
	outFile << "\t\t\t\tdiffuseColor 0 0.5 0\n";
	outFile << "\t\t\t}\n\t\t}\n";
	outFile << "\t\tgeometry Text {\n";
	outFile << "\t\t\tstring [\""<<force<<" kN\"]\n";
	outFile << "\t\t\t\tfontStyle FontStyle {\n";
	outFile << "\t\t\t\tfamily \"SANS\"\n";
	outFile << "\t\t\t\tjustify \"MIDDLE\"\n";
	outFile << "\t\t\t\tstyle \"BOLD\"\n";
	outFile << "\t\t\t\tsize 0.6\n\t\t\t}\n\t\t}\n\t}\n}\n\n";
}


void vrml_axes (ofstream &outFile, char* my_name) {
// Draw in the output vrml file, canvas, background, heading, and axis
//  outFile: pointer to the output vrml file
//  my_name: my name to be shown in the heading
	
	// Create Header
	outFile << "#VRML V2.0 utf8\n";
	outFile << "#------------------------------------------------\n";
	outFile << "# 24-311: Numerical Methods \n";
	outFile << "# "<<MY_NAME<<"\n";
	outFile << "# Gauss Jordan with Partial Pivoting Output\n";
	outFile << "#------------------------------------------------\n\n";

	// Set up background
	outFile << "# Specify the background color\n";
	outFile << "#-----------------------------------\n";
	outFile << "Background {\n\tskyColor 1 1 1\n}\n\n"; // White background

	// Put text heading on the VRML screen
	outFile << "# Draw texts\n";
	outFile << "#-----------------------------------\n";
	outFile << "Transform {\n";
	outFile << "\ttranslation 0 8 0\n";
	outFile << "\tchildren Shape {\n";
	outFile << "\t\tappearance Appearance {\n";
	outFile << "\t\t\tmaterial Material {\n";
	outFile << "\t\t\t\tdiffuseColor 0 0 0\n";
	outFile << "\t\t\t}\n\t\t}\n";
	outFile << "\t\tgeometry Text {\n";
	outFile << "\t\t\tstring [\"24-311: Numerical Methods\",\n";
	outFile << "\t\t\t\"Gauss Jordan with Partial Pivoting\",\n";
	outFile << "\t\t\t\""<<MY_NAME<<"\"]\n";
	outFile << "\t\t\tfontStyle FontStyle {\n";
	outFile << "\t\t\t\tfamily \"SANS\"\n";
	outFile << "\t\t\t\tjustify \"MIDDLE\"\n";
	outFile << "\t\t\t\tstyle \"BOLD\"\n";
	outFile << "\t\t\t\tsize 0.6\n\t\t\t}\n\t\t}\n\t}\n}\n\n";

	// Add the x-axis
	outFile << "# Define the x axis\n";
	outFile << "#-----------------------------------\n";
	outFile << "Transform {\n";
	outFile << "\ttranslation 0 0 0\n";
	outFile << "\tchildren DEF AXIS Shape {\n";
	outFile << "\t\tappearance Appearance {\n";
	outFile << "\t\t\tmaterial Material {\n";
	outFile << "\t\t\t\tdiffuseColor 0.0 0.0 0.0\n\t\t\t}\n\t\t}\n";
	outFile << "\t\tgeometry Extrusion {\n";
	outFile << "\t\t\tcrossSection [1 0, 0 -1, -1 0, 0 1, 1 0]\n";
	outFile << "\t\t\tscale [0.035 0.035, 0.035 0.035, 0.15 0.15, 0 0]\n";
	outFile << "\t\t\tspine [0 0 0, 6 0 0, 6 0 0, 6.5 0 0]\n\t\t}\n\t}\n}\n\n";

	// Add the y-axis
	outFile << "# Draw the y axis\n";
	outFile << "#-----------------------------------\n";
	outFile << "Transform {\n";
	outFile << "\trotation 0 0 1 1.5707\n";
	outFile << "\tchildren USE AXIS\n}\n\n";

	// Add the z-axis
	outFile << "# Draw the z axis\n";
	outFile << "#-----------------------------------\n";
	outFile << "Transform {\n";
	outFile << "\trotation 0 1 0 -1.5707\n";
	outFile << "\tchildren USE AXIS\n}\n\n";
}
